raise

package
v0.0.0-...-71a60af Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 25, 2024 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Copyright © 2024 Ixo

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SuperSimple

func SuperSimple(original_string string, math_flag bool, ext_flag bool)

uses superreplace function raw to replace any possible characters with superscript version

func SuperUpReg

func SuperUpReg(original_string string, math_flag bool, ext_flag bool)

Replace matching characters after a "^" with their superscript equivalent

TODO add a flag to make it so each number needs a "^" rather than catching all matching ones

Types

This section is empty.

Jump to