Documentation
¶
Overview ¶
Copyright © 2024 Ixo
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SuperSimple ¶
uses superreplace function raw to replace any possible characters with superscript version
func SuperUpReg ¶
Replace matching characters after a "^" with their superscript equivalent
TODO add a flag to make it so each number needs a "^" rather than catching all matching ones
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.